@@ -193,6 +193,7 @@ function editInboundObjectFn(
     const argPos = parseInt(argPosRaw, 10);
     if ( isNaN(argPos) ) { return; }
     const getArgPos = args => {
+        if ( Array.isArray(args) === false ) { return; }
         if ( argPos >= 0 ) {
             if ( args.length <= argPos ) { return; }
             return argPos;
@@ -216,11 +217,11 @@ function editInboundObjectFn(
         return objAfter;
     };
     proxyApplyFn(propChain, function(context) {
-        const i = getArgPos(context.args);
+        const i = getArgPos(context.callArgs);
         if ( i !== undefined ) {
-            const obj = editObj(context.args[i]);
+            const obj = editObj(context.callArgs[i]);
             if ( obj ) {
-                context.args[i] = obj;
+                context.callArgs[i] = obj;
             }
         }
         return context.reflect();
